part of modern_form_core;


Future dialog({
  Function onTapOk,
  Function onTapCancel,
  String cancelButtonText,
  String okButtonText,
  String contentText,
  @required String titleText,
  Widget content,
  bool barrierDismissible = true,
  bool returnAutomatic,
}) {
  BuildContext context = ModernFormGlobalContext.context;
  Size size = MediaQuery.of(context).size;

  return showDialog(
    barrierDismissible: barrierDismissible,
    context: context,
    builder: (BuildContext context) {
      return ConstrainedBox(
        constraints: BoxConstraints(
          maxWidth: size.width > ModernFormUtils.webBreakdown
              ? size.width * .4
              : size.width * .6,
        ),
        child: LayoutBuilder(
          builder: (context, constraints) {
            if (Theme.of(context).platform == TargetPlatform.iOS) {
              return CupertinoAlertDialog(
                title: Text(
                  titleText ?? "",
                  style: TextStyle(fontWeight: FontWeight.w500),
                ),
                content: content ?? Text("$contentText"),
                actions: <Widget>[
                  cancelButtonText != null && cancelButtonText.isNotEmpty
                      ? CupertinoDialogAction(
                          child: Text(
                            cancelButtonText,
                            style: TextStyle(
                                color: Colors.red, fontWeight: FontWeight.w600),
                          ),
                          onPressed: onTapCancel ??
                              () {
                                Navigator.pop(context, false);
                              },
                        )
                      : Container(),
                  okButtonText != null && okButtonText.isNotEmpty
                      ? CupertinoDialogAction(
                          child: Text(
                            okButtonText,
                            style: TextStyle(
                                color: Colors.blue,
                                fontWeight: FontWeight.w600),
                          ),
                          onPressed: () {
                            if (returnAutomatic == null || returnAutomatic) {
                              Navigator.pop(context, true);
                            }
                            if (onTapOk != null) {
                              onTapOk();
                            }
                          },
                        )
                      : Container(),
                ],
              );
            } else {
              return AlertDialog(
                title: Text(
                  titleText ?? "",
                  style: TextStyle(fontWeight: FontWeight.w500),
                ),
                shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7)),
                content: content ?? Text("$contentText"),
                actions: <Widget>[
                  cancelButtonText != null && cancelButtonText.isNotEmpty
                      ? FlatButton(
                          child: Text(
                            cancelButtonText,
                            style: TextStyle(
                                color: Colors.red, fontWeight: FontWeight.w600),
                          ),
                          onPressed: onTapCancel ??
                              () {
                                Navigator.pop(context, false);
                              },
                        )
                      : Container(),
                  okButtonText != null && okButtonText.isNotEmpty
                      ? FlatButton(
                          child: Text(
                            okButtonText,
                            style: TextStyle(
                                color: Colors.blue,
                                fontWeight: FontWeight.w600),
                          ),
                          onPressed: () {
                            if (returnAutomatic == null || returnAutomatic) {
                              Navigator.pop(context, true);
                            }
                            if (onTapOk != null) {
                              onTapOk();
                            }
                          },
                        )
                      : Container(),
                ],
              );
            }
          },
        ),
      );
    },
  );
}
