part of modern_form_core;

Future<List<String>> showBottomSheetCheckboxIten(
  context, {
  @required List<String> list,
  @required List<String> listSelected,
  @required String title,
  TextStyle titleStyle,
  bool forceMenu = false,
}) async {
  List<String> _listSelected = List.from(listSelected);

  if (forceMenu == null) {
    forceMenu = false;
  }
  if (MediaQuery.of(context).size.width > ModernFormUtils.webBreakdown ||
      forceMenu) {
    List<menu.PopupMenuEntry<String>> items = [];

    list.forEach((element) {
      items.add(menu.PopupMenuItem(
        value: element,
        onTapEnabled: false,
        child: _ItenCheckBox(
          title: element,
          isSelected: _listSelected.contains(element),
          onChanged: (value) {
            if (_listSelected.contains(element)) {
              _listSelected.remove(element);
            } else {
              _listSelected.add(element);
            }
          },
        ),
      ));
    });
    if (items != null && items.isNotEmpty) {
      await menu.showMenu(
        context: context,
        position: menu.modernFormPopupMenuPosition(
            context, menu.ModernFormPopupMenuLocation.BottomLeft),
        items: items,
        maxHeight: MediaQuery.of(context).size.height * .3,
      );
    }
  } else {
    List<Widget> widgets = <Widget>[];

    list.forEach(
      (element) => widgets.add(
        _ItenCheckBox(
          title: element,
          isSelected: _listSelected.contains(element),
          onChanged: (value) {
            if (_listSelected.contains(element)) {
              _listSelected.remove(element);
            } else {
              _listSelected.add(element);
            }
          },
        ),
      ),
    );
    await showModalBottomSheet(
      isScrollControlled: true,
      context: context,
      builder: (context) {
        return ConstrainedBox(
          constraints: BoxConstraints(
              maxHeight: MediaQuery.of(context).size.height * .7),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              ModernFormBottonSheetLabel(
                label: title,
                labelStyle: titleStyle,
              ),
              Expanded(
                child: ListView(
                  padding:
                      EdgeInsets.symmetric(vertical: ScreenUtil().setSp(15)),
                  children: widgets,
                ),
              ),
            ],
          ),
        );
      },
    );
  }
  return _listSelected;
}

class _ItenCheckBox extends StatefulWidget {
  final String title;
  final bool isSelected;
  final void Function(bool) onChanged;
  const _ItenCheckBox({Key key, this.title, this.isSelected = false, this.onChanged})
      : super(key: key);

  @override
  _ItenCheckBoxState createState() => _ItenCheckBoxState();
}

class _ItenCheckBoxState extends State<_ItenCheckBox> {
  bool isSelected = false;
  @override
  void initState() {
    isSelected = widget.isSelected;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
        padding: EdgeInsets.only(
            bottom: ScreenUtil().setSp(13), left: ScreenUtil().setSp(10)),
        child: InkWell(
          onTap: () {
            widget.onChanged(!isSelected);
            setState(() {
              isSelected = !isSelected;
            });
          },
          child: Row(
            children: <Widget>[
              Checkbox(
                value: isSelected,
                activeColor: Theme.of(context).primaryColor,
                onChanged: (value) {
                  widget.onChanged(value);
                  setState(() {
                    isSelected = value;
                  });
                },
              ),
              Expanded(
                child: Wrap(
                  crossAxisAlignment: WrapCrossAlignment.start,
                  children: [
                    Text(
                      widget?.title ?? "",
                      style: TextStyle(fontSize: ScreenUtil().setSp(15)),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ));
  }
}
