part of modern_form_core;

class ModernFormMultiTextPicker<T> extends StatelessWidget {
  final String label;
  final String helperText;
  final String buttonLabel;
  final List<String> suggestions;
  final void Function(List<String>) onChangedSuggestions;
  final List<ModernFormBottomSheetModel<T>> list;
  final void Function(List<T>) onChangedList;
  final bool forceMenu;
  final bool moveEnable;

  final List<String> suggestionsValue;
  final List<ModernFormBottomSheetModel<T>> listValue;
  final String Function(List<String>) validator;

  const ModernFormMultiTextPicker({
    Key key,
    this.label,
    this.suggestions,
    this.list,
    this.forceMenu,
    this.onChangedList,
    this.onChangedSuggestions,
    this.suggestionsValue,
    this.listValue,
    this.buttonLabel,
    this.validator,
    this.helperText,
    this.moveEnable,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    List<String> itens = listValue?.map((e) => e.text)?.toList();
    List<String> initialValue = suggestionsValue ?? itens;
    List<String> _suggestions =
        suggestions ?? list?.map((e) => e.text)?.toList() ?? <String>[];

    int length = _suggestions?.length ?? 0;

    bool _forceMenu = forceMenu ?? true;

    if (!kIsWeb && length > 5) {
      _forceMenu = false;
    }

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(label ?? "", style: ModernFormTextStyle.moderFormLabelStyle),
        helperText != null
            ? Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setHeight(5)),
                child: Text(helperText ?? "",
                    style: ModernFormTextStyle.moderFormHelperStyle),
              )
            : SizedBox(),
        validator != null && validator(initialValue) != null
            ? Text(validator(initialValue) ?? "",
                style: ModernFormTextStyle.moderFormErrorStyle)
            : Container(),
        ModernFormFilterWithCheckboxIten(
          initialValue: initialValue,
          bottomSheetLabelText: "Selecione",
          buttonText: buttonLabel ?? "Adicionar",
          forceMenu: _forceMenu,
          suggestions: _suggestions,
          moveEnable: moveEnable,
          onChanged: (List<String> selecteds) {
            if (onChangedSuggestions != null) {
              onChangedSuggestions(selecteds);
            }
            if (onChangedList != null) {
              List<T> _values = <T>[];
              selecteds?.forEach((element) {
                ModernFormBottomSheetModel<T> v = list
                    .firstWhere((e) => e.text == element, orElse: () => null);
                if (v != null) {
                  _values.add(v.value);
                }
              });
              onChangedList(_values);
            }
          },
        ),
      ],
    );
  }
}
